@@ -26,6 +26,7 @@ v = rnorm(1:n) * as_units("s")
 plot(u, v)
 plot(u, type = 'l')
 hist(u)
+boxplot(u)
 
-units_options(sep = c("~~~", "~"), group = c("", "")) # more space, parenthesis
+units_options(sep = c("~~~", "~"), group = c("", "")) # more space, no brackets
 units_options(sep = c("~", "~"), group = c("[", "]"), negative_power = FALSE, parse = TRUE)
